==> jc-1.4.0.tar.gz: java/nio/ReadOnlyBufferException.h <==
// public class java.nio.ReadOnlyBufferException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c4b275d49bb21d98 java_lang_UnsupportedOperationException
// @dep_class 42fd78c0e025a665 java_nio_ReadOnlyBufferException

// header file dependencies
// @dep_header java_lang_UnsupportedOperationException

#include "java/lang/UnsupportedOperationException.h"

#ifndef _JC_java_nio_ReadOnlyBufferException_H_
#define _JC_java_nio_ReadOnlyBufferException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_ReadOnlyBufferException$sub_refs	_jc_java_nio_ReadOnlyBufferException$sub_refs;
typedef struct _jc_java_nio_ReadOnlyBufferException$sub_nonrefs	_jc_java_nio_ReadOnlyBufferException$sub_nonrefs;
typedef struct _jc_java_nio_ReadOnlyBufferException$refs	_jc_java_nio_ReadOnlyBufferException$refs;
typedef struct _jc_java_nio_ReadOnlyBufferException$nonrefs	_jc_java_nio_ReadOnlyBufferException$nonrefs;
typedef struct _jc_java_nio_ReadOnlyBufferException$object	_jc_java_nio_ReadOnlyBufferException$object;

typedef const struct _jc_java_nio_ReadOnlyBufferException$vmethods	_jc_java_nio_ReadOnlyBufferException$vmethods;
typedef const struct _jc_java_nio_ReadOnlyBufferException$vtable	_jc_java_nio_ReadOnlyBufferException$vtable;
typedef const struct _jc_java_nio_ReadOnlyBufferException$vtype	_jc_java_nio_ReadOnlyBufferException$vtype;

// Constructors
extern void _jc_java_nio_ReadOnlyBufferException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_ReadOnlyBufferException$object *);

// Virtual methods structure
struct _jc_java_nio_ReadOnlyBufferException$vmethods {
};

// Vtable
struct _jc_java_nio_ReadOnlyBufferException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_UnsupportedOperationException$vmethods	java_lang_UnsupportedOperationException;
	_jc_java_nio_ReadOnlyBufferException$vmethods	java_nio_ReadOnlyBufferException;
};

// Vtype
struct _jc_java_nio_ReadOnlyBufferException$vtype {
	_jc_type			type;
	_jc_java_nio_ReadOnlyBufferException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_ReadOnlyBufferException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_ReadOnlyBufferException$refs {
    _jc_java_nio_ReadOnlyBufferException$sub_refs	java_nio_ReadOnlyBufferException;
    _jc_java_lang_UnsupportedOperationException$sub_refs	java_lang_UnsupportedOperationException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_ReadOnlyBufferException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_ReadOnlyBufferException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_UnsupportedOperationException$sub_nonrefs	java_lang_UnsupportedOperationException;
    _jc_java_nio_ReadOnlyBufferException$sub_nonrefs	java_nio_ReadOnlyBufferException;
};

// Object instance structure
struct _jc_java_nio_ReadOnlyBufferException$object {
	_jc_java_nio_ReadOnlyBufferException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_ReadOnlyBufferException$vtype	*vtype;
	_jc_java_nio_ReadOnlyBufferException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_ReadOnlyBufferException$vtype _jc_java_nio_ReadOnlyBufferException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_ReadOnlyBufferException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_ReadOnlyBufferException$class_object;

#endif	/* _JC_java_nio_ReadOnlyBufferException_H_ */

==> jc-1.4.6.tar.gz: java/nio/ReadOnlyBufferException.h <==
// public class java.nio.ReadOnlyBufferException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c4b275d49bb21d98 java_lang_UnsupportedOperationException
// @dep_class 42fd78c0e025a665 java_nio_ReadOnlyBufferException

// header file dependencies
// @dep_header java_lang_UnsupportedOperationException

#include "java/lang/UnsupportedOperationException.h"

#ifndef _JC_java_nio_ReadOnlyBufferException_H_
#define _JC_java_nio_ReadOnlyBufferException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_ReadOnlyBufferException$sub_refs	_jc_java_nio_ReadOnlyBufferException$sub_refs;
typedef struct _jc_java_nio_ReadOnlyBufferException$sub_nonrefs	_jc_java_nio_ReadOnlyBufferException$sub_nonrefs;
typedef struct _jc_java_nio_ReadOnlyBufferException$refs	_jc_java_nio_ReadOnlyBufferException$refs;
typedef struct _jc_java_nio_ReadOnlyBufferException$nonrefs	_jc_java_nio_ReadOnlyBufferException$nonrefs;
typedef struct _jc_java_nio_ReadOnlyBufferException$object	_jc_java_nio_ReadOnlyBufferException$object;

typedef const struct _jc_java_nio_ReadOnlyBufferException$vmethods	_jc_java_nio_ReadOnlyBufferException$vmethods;
typedef const struct _jc_java_nio_ReadOnlyBufferException$vtable	_jc_java_nio_ReadOnlyBufferException$vtable;
typedef const struct _jc_java_nio_ReadOnlyBufferException$vtype	_jc_java_nio_ReadOnlyBufferException$vtype;

// Constructors
extern void _jc_java_nio_ReadOnlyBufferException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_ReadOnlyBufferException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_ReadOnlyBufferException$vmethods {
};

// Vtable
struct _jc_java_nio_ReadOnlyBufferException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_UnsupportedOperationException$vmethods	java_lang_UnsupportedOperationException;
	_jc_java_nio_ReadOnlyBufferException$vmethods	java_nio_ReadOnlyBufferException;
};

// Vtype
struct _jc_java_nio_ReadOnlyBufferException$vtype {
	_jc_type			type;
	_jc_java_nio_ReadOnlyBufferException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_ReadOnlyBufferException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_ReadOnlyBufferException$refs {
    _jc_java_nio_ReadOnlyBufferException$sub_refs	java_nio_ReadOnlyBufferException;
    _jc_java_lang_UnsupportedOperationException$sub_refs	java_lang_UnsupportedOperationException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_ReadOnlyBufferException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_ReadOnlyBufferException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_UnsupportedOperationException$sub_nonrefs	java_lang_UnsupportedOperationException;
    _jc_java_nio_ReadOnlyBufferException$sub_nonrefs	java_nio_ReadOnlyBufferException;
};

// Object instance structure
struct _jc_java_nio_ReadOnlyBufferException$object {
	_jc_java_nio_ReadOnlyBufferException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_ReadOnlyBufferException$vtype	*vtype;
	_jc_java_nio_ReadOnlyBufferException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_ReadOnlyBufferException$vtype _jc_java_nio_ReadOnlyBufferException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_ReadOnlyBufferException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_ReadOnlyBufferException$class_object;

#endif	/* _JC_java_nio_ReadOnlyBufferException_H_ */
